/*
 * Name:    edf_to_smv.c
 *
 * Purpose: Converts a SOLEIL EDF format image file to an SMV format
 *          image file.
 *
 * Author:  William Lavender
 *
 *------------------------------------------------------------------------
 *
 * Copyright 2008 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>

#include "mx_util.h"
#include "mx_stdint.h"
#include "mx_image.h"

int
main( int argc, char *argv[] )
{
	MX_IMAGE_FRAME *frame;
	mx_status_type mx_status;

	if ( argc != 3 ) {
		fprintf( stderr,
			"Usage: edf_to_smv edf_filename smv_filename\n" );
		exit(1);
	}

	frame = malloc( sizeof(MX_IMAGE_FRAME) );

	if ( frame == NULL ) {
		fprintf( stderr,
			"Could not allocate memory for MX_IMAGE_FRAME.\n" );
		exit(1);
	}

	mx_status = mx_image_read_edf_file( &frame, argv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	mx_status = mx_image_write_smv_file( frame, argv[2] );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	exit(0);
}

