/*
 * Name:    make_flat.c
 *
 * Purpose: Used to generate an area detector image with all of the
 *          pixels set to the same value.
 *
 * Author:  William Lavender
 *
 *------------------------------------------------------------------------
 *
 * Copyright 2007 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#include "mx_util.h"
#include "mx_stdint.h"
#include "mx_bit.h"
#include "mx_image.h"

int
main( int argc, char *argv[] )
{
	MX_IMAGE_FRAME *flat_frame;
	char *flat_filename;
	unsigned long row_width, column_height, image_bytes, image_value;
	mx_status_type mx_status;

	if ( argc != 5 ) {
		fprintf(stderr,
	    "Usage: make_flat row_width column_height value flat_filename\n" );
		exit(1);
	}

	flat_frame   = NULL;

	row_width = atol( argv[1] );
	column_height = atol( argv[2] );
	image_value = atol( argv[3] );

	flat_filename = argv[4];

	/* Create a new 16-bit empty frame with the requested dimensions. */

	image_bytes = row_width * column_height * 2;

	mx_status = mx_image_alloc( &flat_frame,
					row_width,
					column_height,
					MXT_IMAGE_FORMAT_GREY16,
					mx_native_byteorder(),
					2,
					0,
					image_bytes );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	memset( flat_frame->image_data, image_value, image_bytes );

	mx_status = mx_image_write_smv_file( flat_frame, flat_filename );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	fprintf( stderr,
	"Flat frame '%s' successfully created with value = %lu.\n",
		flat_filename, image_value );

	exit(0);
}

