/*
 * Name:    smv_to_pnm.c
 *
 * Purpose: Converts an SMV format image file to a PNM format image file.
 *
 * Author:  William Lavender
 *
 *------------------------------------------------------------------------
 *
 * Copyright 2007 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#include "mx_util.h"
#include "mx_stdint.h"
#include "mx_image.h"

int
main( int argc, char *argv[] )
{
	MX_IMAGE_FRAME *frame;
	mx_status_type mx_status;

	if ( argc != 3 ) {
		fprintf(stderr,
		"Usage: smv_to_pnm smv_filename pnm_filename\n");
		exit(1);
	}

	frame = malloc( sizeof(MX_IMAGE_FRAME) );

	if ( frame == NULL ) {
		fprintf(stderr,
		"Could not allocate memory for MX_IMAGE_FRAME.\n");
		exit(1);
	}

	mx_status = mx_image_read_smv_file( &frame, argv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	mx_status = mx_image_write_pnm_file( frame, argv[2] );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	exit(0);
}

